=================
tools-meetup-test
=================


.. image:: https://img.shields.io/pypi/v/tools_meetup_test.svg
        :target: https://pypi.python.org/pypi/tools_meetup_test

.. image:: https://img.shields.io/travis/minrk/tools_meetup_test.svg
        :target: https://travis-ci.org/minrk/tools_meetup_test

.. image:: https://readthedocs.org/projects/tools-meetup-test/badge/?version=latest
        :target: https://tools-meetup-test.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status




This is a test package for the Simula tools meetup


* Free software: BSD license
* Documentation: https://tools-meetup-test.readthedocs.io.


Features
--------

* TODO

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
